package VMOMI::GuestFileType;
use parent 'VMOMI::SimpleType';

use strict;
use warnings;

1;
